"""
Note about version numbers:

The version number is tied to the API version of mailchimp that we support.
Version 1.3.0 indicated the first release supporting v1.3 of the API.
"""
__version__ = '1.3.0'
